@@ -1,6 +1,7 @@
-import requests
 from urllib.parse import urlencode
 
+import requests
+
 VK_API_URL = 'https://api.vk.com/method/'
 API_VERSION = '5.102'
 
@@ -15,17 +16,16 @@ class Params:
 
 
 class Method:
-    def __init__(self,session, v, token, url, method):
+    def __init__(self, session, url, method, params):
         self.session = session
         self.url = url
         self.method = method
-        self.params = Params({
-            'v': v,
-            'access_token': token
-        })
+        self.params = params
 
     def __getattr__(self, item):
-        return lambda **params: self.session.get(f'{self.url}{self.method}.{item}?{urlencode(self.params.update(params))}')
+        return lambda **params: self.session.get(
+            f'{self.url}{self.method}.{item}?{urlencode(self.params.update(params))}'
+        )
 
 
 class API:
@@ -34,11 +34,20 @@ class API:
         self.token = token
         self.v = v
         self.session = session
+        self.params = Params({
+            'v': v,
+            'access_token': token
+        })
 
     def __getattr__(self, item):
-        method = Method(self.session, self.v, self.token, self.url, item)
-        return method
+        if item == 'execute':
+            return lambda **params: self.session.get(
+                f'{self.url}execute?{urlencode(self.params.update(params))}'
+            )
+        else:
+            method = Method(self.session, self.url, item, self.params)
+            return method
 
 
-get_api = lambda token, api_version=API_VERSION, session=requests.Session(): API(VK_API_URL, api_version, token, session)
-
+get_api = lambda token, api_version=API_VERSION, session=requests.Session(): API(VK_API_URL, api_version, token,
+                                                                                 session)
